==> SyL-0.12.0.tar.gz: SyL/include/framework/Controller/SyL_ControllerXmlrpc.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerXmlrpc.php,v 1.3 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * JavaScriptϥȥ饯饹
 */
require_once 'SyL_ControllerJs.php';

/**
 * XMLRPCȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream         - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   loadStream       - ¹
 *   3.     executeStream  - ¹
 *   4.       middleStream - ¹Ը塢ӥ塼ɽ¹
 *   5.     renderStream   - ӥ塼ɽ¹
 *   6.   unloadStream     - ӥ塼ɽ¹Ը
 *   7. finalStream        - shutdown
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerXmlrpc.php,v 1.3 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerXmlrpc extends SyL_ControllerJs
{
/*
        // Ķѿå
        if (!isset($_SERVER['CONTENT_TYPE'])) {
            trigger_error("[SyL error] Content-Type header not found", E_USER_ERROR);
        }
        if (!preg_match('/text\/xml/i', $_SERVER['CONTENT_TYPE'])) {
            trigger_error("[SyL error] Invalid Content-Type header", E_USER_ERROR);
        }
        if (!isset($_SERVER['HTTP_USER_AGENT'])) {
            trigger_error("[SyL error] User_Agent header not found", E_USER_ERROR);
        }
        if (!isset($_SERVER['HTTP_HOST'])) {
            trigger_error("[SyL error] Host header not found", E_USER_ERROR);
        }
*/
}

?>

==> SyL-0.14.4.tar.gz: SyL/include/framework/Controller/SyL_ControllerXmlrpc.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerXmlrpc.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * WEBȥ饯饹
 */
require_once 'SyL_ControllerWeb.php';

/**
 * XMLRPCȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream         - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   loadStream       - ¹
 *   3.     executeStream  - ¹
 *   4.       middleStream - ¹Ը塢ӥ塼ɽ¹
 *   5.     renderStream   - ӥ塼ɽ¹
 *   6.   unloadStream     - ӥ塼ɽ¹Ը
 *   7. finalStream        - shutdown
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerXmlrpc.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerXmlrpc extends SyL_ControllerWeb
{
/*
        // Ķѿå
        if (!isset($_SERVER['CONTENT_TYPE'])) {
            trigger_error("[SyL error] Content-Type header not found", E_USER_ERROR);
        }
        if (!preg_match('/text\/xml/i', $_SERVER['CONTENT_TYPE'])) {
            trigger_error("[SyL error] Invalid Content-Type header", E_USER_ERROR);
        }
        if (!isset($_SERVER['HTTP_USER_AGENT'])) {
            trigger_error("[SyL error] User_Agent header not found", E_USER_ERROR);
        }
        if (!isset($_SERVER['HTTP_HOST'])) {
            trigger_error("[SyL error] Host header not found", E_USER_ERROR);
        }
*/
}

?>
